NetworkLogRequest class

Represents a network request log entry

Constructors

NetworkLogRequest({required String id, required String method, required String url, Map<String, dynamic>? headers, dynamic body, required DateTime timestamp})

Properties

body → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, dynamic>?
final
id → String
final
method → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited