NetworkLogStore class

Stores network logs in memory for the developer dashboard. Only works in debug mode or staging environment and limits storage to recent entries.

Properties

hashCode → int
The hash code for this object.
no setterinherited
logCount → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRequest(NetworkLogRequest request) → void
Add a request to the store
addResponse(NetworkLogResponse response) → void
Add a response to the store
clear() → void
Clear all logs
clearLogs() → void
Clear all stored logs.
getLogs() → List<Map<String, dynamic>>
Get all current log entries, most recent first.
getRequest(String id) → Map<String, dynamic>?
Get a request by ID
getResponse(String requestId) → Map<String, dynamic>?
Get a response by request ID
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upsertLog(String transactionId, Map<String, dynamic> logUpdate) → void
Add or update a log entry for a transaction.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → NetworkLogStore
Singleton instance
no setter